@@ -18,7 +18,7 @@
 #include "gui/createpartitiontabledialog.h"
 #include "gui/createpartitiontablewidget.h"
 
-#include <kpmcore/core/device.h>
+#include <core/device.h>
 
 #include <QDialogButtonBox>
 #include <QPushButton>
