@@ -111,7 +111,8 @@ bool loadBackend()
 
 QString suCommand()
 {
-    const QString candidates[] = { QStringLiteral("kdesu"), QStringLiteral("kdesudo"), QStringLiteral("gksudo"), QStringLiteral("gksu") };
+    // First look for KF5 version of kdesu in libexec folder
+    const QString candidates[] = { QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5"/kdesu"), QStringLiteral("kdesu"), QStringLiteral("kdesudo"), QStringLiteral("gksudo"), QStringLiteral("gksu") };
     QString rval;
 
     for (quint32 i = 0; i < sizeof(candidates) / sizeof(candidates[0]); i++) {
